@@ -173,6 +173,8 @@ class QUOTIENT_API Room : public QObject {
     Q_PROPERTY(GetRoomEventsJob* eventsHistoryJob READ eventsHistoryJob NOTIFY
                    eventsHistoryJobChanged)
 
+    Q_PROPERTY(QStringList accountDataEventTypes READ accountDataEventTypes NOTIFY accountDataChanged)
+
 public:
     using Timeline = std::deque<TimelineItem>;
     using PendingEvents = std::vector<PendingEventItem>;
@@ -186,29 +188,31 @@ public:
     //! a "cumulative" changed() signal instead of using individual signals for
     //! each change. Specific enumerators mention these individual signals.
     //! \sa changed
-    enum class Change : uint {
-        None = 0x0, ///< No changes occurred in the room
-        Name = 0x1, ///< \sa namesChanged, displaynameChanged
-        Aliases = 0x2, ///< \sa namesChanged, displaynameChanged
-        CanonicalAlias = Aliases,
-        Topic = 0x4, ///< \sa topicChanged
-        PartiallyReadStats = 0x8, ///< \sa partiallyReadStatsChanged
+    enum class Change : quint32 { // QFlags can't go more than 32-bit
+        None = 0x0, //!< No changes occurred in the room
+        RoomNames = 0x1, //!< \sa namesChanged, displaynameChanged
+        DECL_DEPRECATED_ENUMERATOR(Name, RoomNames),
+        DECL_DEPRECATED_ENUMERATOR(Aliases, RoomNames),
+        DECL_DEPRECATED_ENUMERATOR(CanonicalAlias, RoomNames),
+        // Aliases/CanonicalAlias pre-0.8 = 0x2,
+        Topic = 0x4, //!< \sa topicChanged
+        PartiallyReadStats = 0x8, //!< \sa partiallyReadStatsChanged
         DECL_DEPRECATED_ENUMERATOR(UnreadNotifs, PartiallyReadStats),
-        Avatar = 0x10, ///< \sa avatarChanged
-        JoinState = 0x20, ///< \sa joinStateChanged
-        Tags = 0x40, ///< \sa tagsChanged
+        Avatar = 0x10, //!< \sa avatarChanged
+        JoinState = 0x20, //!< \sa joinStateChanged
+        Tags = 0x40, //!< \sa tagsChanged
         //! \sa userAdded, userRemoved, memberRenamed, memberListChanged,
         //!     displaynameChanged
         Members = 0x80,
-        UnreadStats = 0x100, ///< \sa unreadStatsChanged
+        UnreadStats = 0x100, //!< \sa unreadStatsChanged
         AccountData Q_DECL_ENUMERATOR_DEPRECATED_X(
             "Change::AccountData will be merged into Change::Other in 0.8") =
             0x200,
-        Summary = 0x400, ///< \sa summaryChanged, displaynameChanged
+        Summary = 0x400, //!< \sa summaryChanged, displaynameChanged
         ReadMarker Q_DECL_ENUMERATOR_DEPRECATED_X(
             "Change::ReadMarker will be merged into Change::Other in 0.8") =
             0x800,
-        Highlights = 0x1000, ///< \sa highlightCountChanged
+        Highlights = 0x1000, //!< \sa highlightCountChanged
         //! A catch-all value that covers changes not listed above (such as
         //! encryption turned on or the room having been upgraded), as well as
         //! changes in the room state that the library is not aware of (e.g.,
@@ -225,6 +229,7 @@ public:
     QUO_DECLARE_FLAGS(Changes, Change)
 
     Room(Connection* connection, QString id, JoinState initialJoinState);
+    Q_DISABLE_COPY_MOVE(Room)
     ~Room() override;
 
     // Property accessors
@@ -277,7 +282,9 @@ public:
     int timelineSize() const;
     bool usesEncryption() const;
     RoomEventPtr decryptMessage(const EncryptedEvent& encryptedEvent);
-    void handleRoomKeyEvent(const RoomKeyEvent& roomKeyEvent, const QString& senderId, const QString& olmSessionId);
+    void handleRoomKeyEvent(const RoomKeyEvent& roomKeyEvent,
+                            const QString& senderId,
+                            const QByteArray& olmSessionId);
     int joinedCount() const;
     int invitedCount() const;
     int totalMemberCount() const;
@@ -505,7 +512,7 @@ public:
     //!       it's recommended to ensure that all room members are loaded
     //!       before operating on the result of this function.
     //! \sa lastReadReceipt, allMembersLoaded
-    QSet<QString> userIdsAtEvent(const QString& eventId);
+    QSet<QString> userIdsAtEvent(const QString& eventId) const;
 
     [[deprecated("Use userIdsAtEvent instead")]]
     QSet<User*> usersAtEventId(const QString& eventId);
@@ -626,9 +633,6 @@ public:
     //! \sa unreadStats, lastLocalReadReceipt
     qsizetype notificationCount() const;
 
-    [[deprecated("Use setReadReceipt() to drive changes in notification count")]]
-    Q_INVOKABLE void resetNotificationCount();
-
     //! \brief Get the number of highlights since the last read receipt
     //!
     //! As of 0.7, this is defined by the homeserver as Quotient doesn't process
@@ -637,9 +641,6 @@ public:
     //! \sa unreadStats, lastLocalReadReceipt
     qsizetype highlightCount() const;
 
-    [[deprecated("Use setReadReceipt() to drive changes in highlightCount")]]
-    Q_INVOKABLE void resetHighlightCount();
-
     /** Check whether the room has account data of the given type
      * Tags and read markers are not supported by this method _yet_.
      */
@@ -652,6 +653,10 @@ public:
      */
     const EventPtr& accountData(const QString& type) const;
 
+    //! Get a list of all room account data events
+    //! \return A list of event types that exist in the room
+    QStringList accountDataEventTypes() const;
+
     QStringList tagNames() const;
     TagsMap tags() const;
     TagRecord tag(const QString& name) const;
